#!/bin/sh
if [ $# -ne 1 ]; then
     echo "Please call script with name of release as the sole argument."
     exit 127
fi

SVN=http://ww2.biocase.org/svn/bps2/
REV="`svn info | grep -o 'Rev: .*$' | sed 's/Rev: //'`"
DATE="`svn info | grep -o 'nderungsdatum: *....-..-.. ..:..:.. .....' | sed 's/nderungsdatum: *//' `"
# build & software names
VERSION="$1"
BUILD="$1 build($REV)"
RELEASE="${1}_$REV"
SOFTWARE="pywrapper_$RELEASE"


echo "Releasing BPS2!"
echo "Using repository $SVN"
echo ""
echo "Building release $VERSION, build $REV from $DATE"
echo "Updating trunk files with current build number..."
sed "s/^Version *:.*$/Version  : $BUILD/g" INSTALL.TXT > INSTALL.TXT2
sed "s/^Date *:.*$/Date     : $DATE/g" INSTALL.TXT2 > INSTALL.TXT
rm INSTALL.TXT2
sed "s/^Version *:.*$/Version  : $BUILD/g" README.TXT > README.TXT2
sed "s/^Date *:.*$/Date     : $DATE/g" README.TXT2 > README.TXT
rm README.TXT2
cd lib/biocase
sed "s/^__version__ *=.*$/__version__ = '$VERSION'/g" __init__.py > __init__.py2
sed "s/^__build__ *=.*$/__build__ = '$REV'/g" __init__.py2 > __init__.py
sed "s/^__date__ *=.*$/__date__ = '$DATE'/g" __init__.py > __init__.py2
rm __init__.py
mv __init__.py2 __init__.py
cd ../..
 
echo "Committing to trunk..."
svn commit -m "Creating new stable build $BUILD" INSTALL.TXT README.TXT lib/biocase/__init__.py


echo "Remove old build directory"
mkdir build
cd build

echo "Delete existing stable SVN branch ..."
svn del -m "Delete stable branch for copy of new release"  $SVN/branches/stable

echo "Create new stable SVN branch ..."
svn copy -m "Copy the trunk to the stable branch for release" $SVN/trunk $SVN/branches/stable

echo "Remove unnecessary items from stable branch ..."
svn del -m "Not needed for release"  $SVN/branches/stable/release.sh

echo "Create new SVN release_$VERSION ..."
svn copy -m "Copy the stable to the specific release tag" $SVN/branches/stable $SVN/tags/release_$VERSION

echo "Export release ..."
svn export $SVN/branches/stable > /dev/null

echo "Create tar.gz archive"
mv stable provider_software_$VERSION
tar cvf provider_software_$VERSION.tar provider_software_$VERSION/
gzip provider_software_$VERSION.tar
mv provider_software_$VERSION.tar.gz ../
cd ..
rm -r build
echo "Done."
# All done, exit ok
exit 0

